@@ -1,7 +1,5 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
+from io import StringIO
 
-import six
 from babel.numbers import format_decimal
 
 from agate import Table
@@ -32,14 +30,14 @@ class TestPrintBars(AgateTestCase):
     def test_print_bars(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_bars('three', 'one', output=output)
-        lines = output.getvalue().split('\n')  # noqa
+        output.getvalue().split('\n')
 
     def test_print_bars_width(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_bars('three', 'one', width=40, output=output)
         lines = output.getvalue().split('\n')
 
@@ -48,7 +46,7 @@ class TestPrintBars(AgateTestCase):
     def test_print_bars_width_overlap(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_bars('three', 'one', width=20, output=output)
         lines = output.getvalue().split('\n')
 
@@ -94,13 +92,13 @@ class TestPrintBars(AgateTestCase):
     def test_print_bars_with_nulls(self):
         table = Table(self.rows, self.column_names, self.column_types)
 
-        output = six.StringIO()
+        output = StringIO()
         table.print_bars('three', 'two', width=20, printable=True,
                          output=output)
 
         self.assertEqual(output.getvalue(), "three   two\n"
-                                            "a     " + format_decimal(2000, format=u'#,##0') + " |:::::::\n"
+                                            "a     " + format_decimal(2000, format='#,##0') + " |:::::::\n"
                                             "None      - |       \n"
                                             "c         1 |       \n"
                                             "            +------+\n"
-                                            "            0  " + format_decimal(2000, format=u'#,##0') + "\n")
+                                            "            0  " + format_decimal(2000, format='#,##0') + "\n")
